@@ -221,6 +221,14 @@ def get_file_contents(filename: str = None, blob: bytes = None,
         return f.read()
 
 
+def get_file_contents_text(filename: str = None, blob: bytes = None,
+                           encoding = sys.getdefaultencoding(),
+                           **kwargs) -> str:
+    """Returns string contents of a file, or blob."""
+    binary_contents = get_file_contents(filename=filename, blob=blob, **kwargs)
+    return binary_contents.decode(encoding)
+
+
 def get_cmd_output(*args, **kwargs) -> str:
     """Returns text output of a command."""
     encoding = kwargs.get("encoding", ENCODING)
@@ -862,7 +870,7 @@ ext_map = {
         AVAILABILITY: True,
     },
     '.log': {
-        CONVERTER: get_file_contents,
+        CONVERTER: get_file_contents_text,
         AVAILABILITY: True,
     },
     '.odt': {
@@ -882,7 +890,7 @@ ext_map = {
         AVAILABILITY: True,
     },
     '.txt': {
-        CONVERTER: get_file_contents,
+        CONVERTER: get_file_contents_text,
         AVAILABILITY: True,
     },
     None: {  # fallback
