@@ -4,7 +4,7 @@
 # See LICENSE for details.
 
 
-VERSION = '0.2.9'
+VERSION = '0.2.10'
 # Use semantic versioning: http://semver.org/
 
 RECENT_VERSION_HISTORY = """
@@ -15,5 +15,8 @@ RECENT_VERSION_HISTORY = """
   
 - 0.2.8, 2017-04-28
   Fixed DOCX table processing bug, in docx_process_table().
+  
+- 0.2.10, 2017-04-29
+  Text fetch (for converters) was returning bytes, not str; fixed.
 
 """
